//
//  MyController.m
//  iChatDemo
//
//  Created by Mark Alldritt on 27/02/08.
//  Copyright 2008 __MyCompanyName__. All rights reserved.
//
//
//	NOTE:
//
//	I started my work with the information on this Apple web page: 
//
//	http://developer.apple.com/leopard/overview/imframework.html
//
//	The problem is that this page omits to say that you must add a LSCanProvideIMVideoDataSource key with
//	a value of TRUE to the application's Info.plist file.  This is all explained here (Thanks to the folks
//	at Infinite Labs for putting me on the right track):
//
//	http://developer.apple.com/documentation/AppleApplications/Conceptual/InstantMessageProgGuide/Articles/UsingLaunchServices.html#//apple_ref/doc/uid/TP40006595-SW2
//

#import "MyController.h"
#import <InstantMessage/IMAVManager.h>
#import <InstantMessage/IMService.h>


static NSArray* sImages = nil;  // the images we are going to display
static int sNextImage = 0;


@implementation MyController

- (void) _timerDidFire:(NSTimer*) theTimer
{
	if (!sImages)
	{
		//	Cache NSImage instances for each of the jpg images in the app's bundle.  We can then cycle
		//	through them in the application's window.
		NSArray* imagePaths = [[NSBundle mainBundle] pathsForResourcesOfType:@"jpg" inDirectory:nil];
		unsigned int numImages = [imagePaths count];
		NSMutableArray* images = [NSMutableArray arrayWithCapacity:numImages];
		
		for (unsigned int i = 0; i < numImages; ++i)
		{
			NSImage* image = [[NSImage alloc] initByReferencingFile:[imagePaths objectAtIndex:i]];
			
			[images addObject:image];
		}

		sImages = [images retain];
	}

	//	Display the "next" image
	[mImageView setImage:[sImages objectAtIndex:sNextImage++]];
	if (sNextImage >= [sImages count])
		sNextImage = 0;
}

- (void) _handleStateDidChange:(NSNotification*) notification
{
	NSLog(@"_handleStateDidChange: %@", notification);

	IMAVManager *manager = [IMAVManager sharedAVManager];

	switch ([manager state])
	{
	case IMAVRequested:
		//	iChat is beginning a iChat Theatre session...
		[manager setVideoDataSource:miChatView];
		[manager start];
		break;
	}
}

- (void) _handleURLToShareDidChange:(NSNotification*) notification
{
	NSLog(@"_handleURLToShareDidChange: %@ (%@)", notification, [[IMAVManager sharedAVManager] URLToShare]);
}

- (void) awakeFromNib
{
	//	Register for iChat Theater notifications
	[[IMService notificationCenter] addObserver:self
									   selector:@selector(_handleStateDidChange:)
										   name:IMAVManagerStateChangedNotification
										 object:nil];
	[[IMService notificationCenter] addObserver:self
									   selector:@selector(_handleURLToShareDidChange:)
										   name:IMAVManagerURLToShareChangedNotification
										 object:nil];

	//	We are going to cycle through a series of images in the image view
	[NSTimer scheduledTimerWithTimeInterval:2.0
									 target:self
								   selector:@selector(_timerDidFire:)
								   userInfo:nil
									repeats:YES];

	//	Display the initial image
	[self _timerDidFire:nil];
}

@end
